# 0.6.1 (June 2024)

- Fix version

# 0.6.0 (June 2024)

- Support --name_by option ([#147](https://github.com/ome/omero-cli-zarr/pull/147))
- Fix export of Plate labels ([#173](https://github.com/ome/omero-cli-zarr/pull/173))
- Use numpy.frombuffer instead of fromstring ([#177](https://github.com/ome/omero-cli-zarr/pull/177))
- Fix theC handling for mask export ([#178](https://github.com/ome/omero-cli-zarr/pull/178))
- Pin ome-zarr-py < 0.12.0 ([#175](https://github.com/ome/omero-cli-zarr/pull/175))
- Add integration tests ([#171](https://github.com/ome/omero-cli-zarr/pull/171))
- Various build and release fixes ([#165](https://github.com/ome/omero-cli-zarr/pull/165), ([#168](https://github.com/ome/omero-cli-zarr/pull/168)))

# 0.5.5 (November 2023)

- Fix install build (pin scm version) ([#159](https://github.com/ome/omero-cli-zarr/pull/159))
- Fix data-type for float-32 images ([#157](https://github.com/ome/omero-cli-zarr/pull/157))


# 0.5.4 (November 2023)

- Fix path/to/image when exporting Plate images ([#146](https://github.com/ome/omero-cli-zarr/pull/146))


# 0.5.3 (May 2023)

- Fix dimension separator in downsampled data ([#144](https://github.com/ome/omero-cli-zarr/pull/144))


# 0.5.2 (May 2023)

- Remove numpy.bool alias ([#143](https://github.com/ome/omero-cli-zarr/pull/143))

# 0.5.1 (November 2022)

- Fix axes "units" to "unit" ([#131](https://github.com/ome/omero-cli-zarr/pull/131))
